"use client";
import React from "react";
import styles from "./loginPage.module.scss";
import Box from "@mui/material/Box";
import Typography from "@mui/material/Typography";
import Grid from "@mui/material/Grid";
import { UTILITY_CONSTANT } from "@/utilities/utilityConstant";
import Link from "next/link";
import CustomizedInputsStyled from "@/ui/CustomizedInputsStyled";
import CustomizedButtons from "@/ui/customizedButtons";
import { useForm } from "react-hook-form";
import { z } from "zod";
import { zodResolver } from "@hookform/resolvers/zod";
import { useState } from "react";
import { loginApi } from "@/services/api/loginApi";
import { FormControl } from "@mui/material";
import CustomTextField from "@/ui/CustomTextField";
import { useRouter } from "next/navigation";
import { useDispatch, useSelector } from "react-redux";
import { RootState } from "@/services/store";
import { setAuthTokens, setUserDetails } from "@/services/store/authSlice";

const loginSchema = z.object({
  username: z.string(),
  password: z.string(),
});

type LoginFormValues = z.infer<typeof loginSchema>;

export default function LoginPage() {
  const router = useRouter();
  const {
    register,
    handleSubmit,
    formState: { errors },
    control,
  } = useForm<LoginFormValues>({
    resolver: zodResolver(loginSchema),
  });
  const [error, setError] = useState("");
  const dispatch = useDispatch();
  const onSubmit = async (data: LoginFormValues) => {
    try {
      const response = await loginApi(data);
      localStorage.setItem("token", response.token);
      localStorage.setItem("refreshToken", response.refreshToken);
      dispatch(
        setAuthTokens({
          token: response.token,
          refreshToken: response.refreshToken,
        })
      );
      dispatch(setUserDetails(response));

      router.push("/home");
    } catch (err) {
      setError("Invalid credentials");
    }
  };

  return (
    <main className={styles.loginPage}>
      <Grid container sx={{ height: "100%" }}>
        <Grid item display={{ xs: "none", md: "block" }} md={7}>
          <Box
            height={"100%"}
            sx={{ background: "var(--primary)" }}
            display={"flex"}
            alignItems={"center"}
            justifyContent={"space-between"}
          >
            <img
              src={UTILITY_CONSTANT.IMAGES.AUTH.LOGIN_BG}
              alt=""
              className={styles.images}
            />
          </Box>
        </Grid>
        <Grid item xs={12} md={5}>
          <Box
            width={"100%"}
            height={"100%"}
            display={"flex"}
            flexDirection={"column"}
            justifyContent={"space-between"}
            alignItems={"flex-start"}
            gap={4}
            paddingInline={5}
            paddingBlock={5}
          >
            <img src={UTILITY_CONSTANT.IMAGES.AUTH.HEADER_LOG} alt="logo" />
            <form onSubmit={handleSubmit(onSubmit)}>
              <Typography variant="h4">Welcome to Convexsol</Typography>
              <Typography variant="h4">Sign in to your account</Typography>
              <Box
                width={"100%"}
                marginBlockStart={"40px"}
                display={"flex"}
                alignItems={"flex-start"}
                flexDirection={"column"}
                gap={3}
              >
                <CustomTextField
                  name="username"
                  control={control}
                  label="Username"
                  error={!!errors.username}
                  helperText={errors.username?.message}
                />
                <CustomTextField
                  name="password"
                  control={control}
                  label="Password"
                  type="password"
                  error={!!errors.password}
                  helperText={errors.password?.message}
                />
              </Box>
              <Box width={"100%"} marginBlockStart={"20px"}>
                <CustomizedButtons btnType="submit" label={"Sign In"} />
              </Box>
            </form>
            <Box
              width={"100%"}
              display={"flex"}
              alignItems={"center"}
              justifyContent={"space-between"}
              flexWrap={"wrap"}
              gap={2}
            >
              <Typography variant="caption">
                © 2024 ConvexSol. Pvt.Ltd. All rights reserved.
              </Typography>
              <Typography variant="caption">
                <Link href={"#"}>Privacy Policy</Link> |{" "}
                <Link href={"#"}>Terms of Use</Link>
              </Typography>
            </Box>
          </Box>
        </Grid>
      </Grid>
    </main>
  );
}
